@@ -80,11 +80,11 @@ static const char* KEY_CONFIG_TOOL   = "config_tool";
 static const char* KEY_CUSTOM_FORMAT = "custom_format";
 static const char* KEY_SHOW_WEEK     = "show_week_numbers";
 
+#define FALLBACK_CONFIG_TOOL "time-admin"
+
 static const char *clock_config_tools [] = {
-	"system-config-date",
-	"redhat-config-date",
-        "/sbin/yast2 timezone",
-	"time-admin",
+	CLOCK_TIME_UTILITY,
+	FALLBACK_CONFIG_TOOL
 };
 
 /* Needs to match the indices in the combo */
@@ -243,19 +243,34 @@ set_tooltip (GtkWidget  *applet,
 }
 
 static void
-clock_set_timeout (ClockData *cd)
+clock_set_timeout (ClockData *cd,
+		   time_t     now)
 {
 	int timeouttime;
 
-	if (cd->format == CLOCK_FORMAT_INTERNET)
-		timeouttime = INTERNETSECOND;
- 	else {
+	if (cd->format == CLOCK_FORMAT_INTERNET) {
+		int itime_ms;
+
+		itime_ms = ((unsigned int) (get_itime (now) * 1000));
+
+		if (!cd->showseconds)
+			timeouttime = (999 - itime_ms % 1000) * 86.4 + 1;
+		else {
+			struct timeval tv;
+			gettimeofday (&tv, NULL);
+			itime_ms += (tv.tv_usec * 86.4) / 1000;
+			timeouttime = ((999 - itime_ms % 1000) * 86.4) / 100 + 1;
+		}
+	} else {
  		struct timeval tv;
+
 		gettimeofday (&tv, NULL);
- 		timeouttime = (1000000 - tv.tv_usec)/1000+1;
+ 		timeouttime = (G_USEC_PER_SEC - tv.tv_usec)/1000+1;
+
+		/* timeout of one minute if we don't care about the seconds */
  		if (cd->format != CLOCK_FORMAT_UNIX &&
 		    !cd->showseconds)
- 			timeouttime += 1000 * (59 - cd->current_time % 60);
+ 			timeouttime += 1000 * (59 - now % 60);
  	}
 	
 	cd->timeout = g_timeout_add (timeouttime,
@@ -275,8 +290,8 @@ clock_timeout_callback (gpointer data)
 	    cd->format != CLOCK_FORMAT_UNIX &&
 	    cd->format != CLOCK_FORMAT_CUSTOM) {
 		if (cd->format == CLOCK_FORMAT_INTERNET && 
-		    (long)get_itime (new_time) !=
-		    (long)get_itime (cd->current_time)) {
+		    (unsigned int)get_itime (new_time) !=
+		    (unsigned int)get_itime (cd->current_time)) {
 			update_clock (cd);
 		} else if ((cd->format == CLOCK_FORMAT_12 ||
 			    cd->format == CLOCK_FORMAT_24) &&
@@ -287,7 +302,7 @@ clock_timeout_callback (gpointer data)
 		update_clock (cd);
 	}
 
-	clock_set_timeout (cd);
+	clock_set_timeout (cd, new_time);
 
 	return FALSE;
 }
@@ -482,7 +497,7 @@ update_clock (ClockData * cd)
 		if (cd->showseconds)
 			utf8 = g_strdup_printf ("@%3.2f", itime);
 		else
-			utf8 = g_strdup_printf ("@%3.0f", itime);
+			utf8 = g_strdup_printf ("@%3d", (unsigned int) itime);
 	} else if (cd->format == CLOCK_FORMAT_CUSTOM) {
 		char *timeformat = g_locale_from_utf8 (cd->custom_format, -1,
 						       NULL, NULL, NULL);
@@ -564,7 +579,7 @@ refresh_clock_timeout(ClockData *cd)
 
 	update_clock (cd);
 	
-	clock_set_timeout (cd);
+	clock_set_timeout (cd, cd->current_time);
 }
 
 static void
@@ -1933,7 +1948,8 @@ copy_time (BonoboUIComponent *uic,
 		if (cd->showseconds)
 			g_snprintf (string, sizeof (string), "@%3.2f", itime);
 		else
-			g_snprintf (string, sizeof (string), "@%3.0f", itime);
+			g_snprintf (string, sizeof (string), "@%3d",
+				    (unsigned int) itime);
 	} else {
 		struct tm *tm;
 		char      *format;
@@ -2002,14 +2018,30 @@ copy_date (BonoboUIComponent *uic,
 	g_free (utf8);
 }
 
+static void
+on_config_tool_exited (GPid     pid,
+                       gint     status,
+                       gpointer data)
+{
+  ClockData *clock;
+
+  clock = (ClockData *) data;
+
+  refresh_clock (clock);
+
+  g_spawn_close_pid (pid);
+}
+
 static gboolean
 try_config_tool (GdkScreen  *screen,
-		 const char *tool)
+		 const char *tool,
+		 ClockData  *cd)
 {
 	GtkWidget *dialog;
 	GError    *err;
 	char     **argv;
-        char      *path;
+	char      *path;
+	GPid       pid;
 
         if (!tool || tool[0] == '\0')
                 return FALSE;
@@ -2029,12 +2061,14 @@ try_config_tool (GdkScreen  *screen,
                                  NULL,
                                  argv,
                                  NULL,
-                                 G_SPAWN_SEARCH_PATH,
-                                 NULL,
+                                 G_SPAWN_SEARCH_PATH|G_SPAWN_DO_NOT_REAP_CHILD,
                                  NULL,
                                  NULL,
+                                 &pid,
                                  &err)) {
-                g_strfreev (argv);
+
+		g_child_watch_add (pid, on_config_tool_exited, cd); 
+		g_strfreev (argv);
 		return TRUE;
 	}
 
@@ -2071,11 +2105,11 @@ config_date (BonoboUIComponent *uic,
 
 	screen = gtk_widget_get_screen (cd->applet);
 
-	if (try_config_tool (screen, cd->config_tool))
+	if (try_config_tool (screen, cd->config_tool, cd))
 		return;
 	
 	for (i = 0; i < G_N_ELEMENTS (clock_config_tools); i++)
-		if (try_config_tool (screen, clock_config_tools [i]))
+		if (try_config_tool (screen, clock_config_tools [i], cd))
 			return;
 		
 	dialog = gtk_message_dialog_new (NULL,
