@@ -38,6 +38,7 @@
 #include "panel-lockdown.h"
 #include "panel-compatibility.h"
 #include "panel-ditem-editor.h"
+#include "panel-icon-names.h"
 
 static GdkScreen *
 launcher_get_screen (Launcher *launcher)
@@ -569,30 +570,6 @@ create_launcher (const char *location)
 	return launcher;
 }
 
-static char *
-guess_icon_from_exec (GtkIconTheme *icon_theme,
-		      GKeyFile     *key_file)
-{
-	char *exec;
-	char *icon_name;
-	char *retval;
-
-	exec = panel_util_key_file_get_string (key_file, "Exec");
-
-	if (!exec || !exec [0]) {
-		g_free (exec);
-		return NULL;
-	}
-
-	icon_name = g_path_get_basename (exec);
-	retval = panel_find_icon (icon_theme, icon_name, 48);
-
-	g_free (exec);
-	g_free (icon_name);
-
-	return retval;
-}
-
 static void
 setup_button (Launcher *launcher)
 {
@@ -640,8 +617,10 @@ setup_button (Launcher *launcher)
 	if (!icon)
 		icon = guess_icon_from_exec (BUTTON_WIDGET (launcher->button)->icon_theme,
 					     launcher->key_file);
+	if (!icon)
+		icon = g_strdup (PANEL_ICON_LAUNCHER);
 
-	button_widget_set_icon_name (BUTTON_WIDGET (launcher->button), sure_string (icon));
+	button_widget_set_icon_name (BUTTON_WIDGET (launcher->button), icon);
 	g_free (icon);
 }
 
@@ -796,7 +775,7 @@ launcher_properties (Launcher  *launcher)
 		return;
 	}
 
-	launcher->prop_dialog = panel_ditem_editor_new (GTK_WINDOW (PANEL_WIDGET (launcher->info->widget->parent)->toplevel),
+	launcher->prop_dialog = panel_ditem_editor_new (NULL,
 							launcher->key_file,
 							launcher->location,
 							_("Launcher Properties"));
@@ -1025,7 +1004,7 @@ panel_launcher_create_from_info (PanelToplevel *toplevel,
 	if (panel_util_key_file_to_file (key_file, location, &error)) {
 		panel_launcher_create (toplevel, position, location);
 	} else {
-		panel_error_dialog (NULL,
+		panel_error_dialog (GTK_WINDOW (toplevel),
 				    gtk_window_get_screen (GTK_WINDOW (toplevel)),
 				    "cannot_save_launcher", TRUE,
 				    _("Could not save launcher"),
