@@ -41,13 +41,13 @@
 #include "panel-config-global.h"
 #include "panel-stock-icons.h"
 #include "panel-action-button.h"
-#include "panel-recent.h"
 #include "panel-profile.h"
 #include "panel-menu-button.h"
 #include "panel-menu-items.h"
 #include "panel-globals.h"
 #include "panel-run-dialog.h"
 #include "panel-lockdown.h"
+#include "panel-icon-names.h"
 
 typedef struct {
 	GtkWidget    *pixmap;
@@ -216,10 +216,6 @@ menus_have_icons_changed (GConfClient *client,
 		if (!image)
 			continue;
 
-		/* A forced image is always on */
-		if (g_object_get_data (G_OBJECT (item), "Panel:ForceImage"))
-			continue;
-
 		cur_image = gtk_image_menu_item_get_image (
 					GTK_IMAGE_MENU_ITEM (item));
 
@@ -884,14 +880,6 @@ restore_grabs(GtkWidget *w, gpointer data)
 	gtk_grab_add (GTK_WIDGET (menu));
 }
 
-static void
-menu_destroy_context_menu (GtkWidget *item,
-			   GtkWidget *menu)
-{
-	g_signal_handlers_disconnect_by_func (menu, restore_grabs, item);
-	gtk_widget_destroy (menu);
-}
-
 static GtkWidget *
 create_item_context_menu (GtkWidget   *item,
 			  PanelWidget *panel_widget)
@@ -926,11 +914,13 @@ create_item_context_menu (GtkWidget   *item,
 		return NULL;
 
 	menu = create_empty_menu ();
-	g_object_set_data (G_OBJECT (item), "panel-item-context-menu", menu);
-	g_object_set_data (G_OBJECT (menu), "menu_panel", panel_widget);
+	g_object_set_data_full (G_OBJECT (item),
+				"panel-item-context-menu",
+				g_object_ref (menu),
+				(GDestroyNotify) g_object_unref);
+	gtk_object_sink (GTK_OBJECT (menu));
 
-	g_signal_connect (item, "destroy",
-			  G_CALLBACK (menu_destroy_context_menu), menu);
+	g_object_set_data (G_OBJECT (menu), "menu_panel", panel_widget);
 	g_signal_connect (menu, "deactivate",
 			  G_CALLBACK (restore_grabs), item);
 
@@ -1436,7 +1426,7 @@ create_submenu_entry (GtkWidget          *menu,
 					panel_menu_icon_get_size (),
 					NULL,
 					gmenu_tree_directory_get_icon (directory),
-					"gnome-fs-directory");
+					PANEL_ICON_FOLDER);
 
 	setup_menuitem (menuitem,
 			panel_menu_icon_get_size (),
