@@ -861,8 +861,11 @@ panel_applet_frame_reload_response (GtkWidget        *dialog,
 
 	g_return_if_fail (PANEL_IS_APPLET_FRAME (frame));
 
-	if (!frame->priv->iid || !frame->priv->panel)
+	if (!frame->priv->iid || !frame->priv->panel) {
+		g_object_unref (frame);
+		gtk_widget_destroy (dialog);
 		return;
+	}
 
 	info = frame->priv->applet_info;
 
@@ -977,6 +980,9 @@ panel_applet_frame_cnx_broken (ORBitConnection  *cnx,
 				_("_Reload"), GTK_RESPONSE_YES,
 				NULL);
 
+	gtk_dialog_set_default_response (GTK_DIALOG (dialog),
+					 GTK_RESPONSE_YES);
+
 	gtk_window_set_screen (GTK_WINDOW (dialog), screen);
 
 	g_signal_connect (dialog, "response",
@@ -984,6 +990,9 @@ panel_applet_frame_cnx_broken (ORBitConnection  *cnx,
 			  g_object_ref (frame));
 
 	panel_widget_register_open_dialog (frame->priv->panel, dialog);
+	gtk_window_set_urgency_hint (GTK_WINDOW (dialog), TRUE);
+	/* FIXME: http://bugzilla.gnome.org/show_bug.cgi?id=165132 */
+	gtk_window_set_title (GTK_WINDOW (dialog), _("Error"));
 
 	gtk_widget_show (dialog);
 	g_free (applet_name);
@@ -1048,7 +1057,6 @@ panel_applet_frame_loading_failed (PanelAppletFrame  *frame,
 		gtk_dialog_add_buttons (GTK_DIALOG (dialog),
 					GTK_STOCK_OK, LOADING_FAILED_RESPONSE_DONT_DELETE,
 					NULL);
-		gtk_dialog_set_default_response (GTK_DIALOG (dialog), LOADING_FAILED_RESPONSE_DONT_DELETE);
 	} else {
 		gtk_message_dialog_format_secondary_text (GTK_MESSAGE_DIALOG (dialog),
 					_("Do you want to delete the applet "
@@ -1057,9 +1065,11 @@ panel_applet_frame_loading_failed (PanelAppletFrame  *frame,
 					PANEL_STOCK_DONT_DELETE, LOADING_FAILED_RESPONSE_DONT_DELETE,
 					GTK_STOCK_DELETE, LOADING_FAILED_RESPONSE_DELETE,
 					NULL);
-		gtk_dialog_set_default_response (GTK_DIALOG (dialog), LOADING_FAILED_RESPONSE_DELETE);
 	}
 
+	gtk_dialog_set_default_response (GTK_DIALOG (dialog),
+					 LOADING_FAILED_RESPONSE_DONT_DELETE);
+
 	gtk_window_set_screen (GTK_WINDOW (dialog),
 			       gtk_window_get_screen (GTK_WINDOW (frame->priv->panel->toplevel)));
 
@@ -1067,6 +1077,11 @@ panel_applet_frame_loading_failed (PanelAppletFrame  *frame,
 			  G_CALLBACK (panel_applet_frame_loading_failed_response),
 			  g_strdup (id));
 
+	panel_widget_register_open_dialog (frame->priv->panel, dialog);
+	gtk_window_set_urgency_hint (GTK_WINDOW (dialog), TRUE);
+	/* FIXME: http://bugzilla.gnome.org/show_bug.cgi?id=165132 */
+	gtk_window_set_title (GTK_WINDOW (dialog), _("Error"));
+
 	gtk_widget_show_all (dialog);
 
 	g_free (frame->priv->iid);
