@@ -33,6 +33,7 @@
 #include <libgnomeui/gnome-help.h>
 #include <libgnomevfs/gnome-vfs.h>
 #include "panel-ditem-editor.h"
+#include "panel-icon-names.h"
 #include "panel-util.h"
 #include "panel-marshal.h"
 
@@ -112,7 +113,7 @@ static ComboItem type_items [] = {
 	  PANEL_DITEM_EDITOR_TYPE_APPLICATION          },
 	{ N_("Application in Terminal"), "Application",
 	  PANEL_DITEM_EDITOR_TYPE_TERMINAL_APPLICATION },
-	{ N_("File"),                    "Link",
+	{ N_("Location"),                "Link",
 	  PANEL_DITEM_EDITOR_TYPE_LINK                 },
 	/* FIXME: hack hack hack: we will remove this item from the combo
 	 * box if we show it */
@@ -171,6 +172,10 @@ static void type_combo_changed (PanelDItemEditor *dialog);
 
 static void response_cb (GtkDialog *dialog,
 			 gint       response_id);
+
+static void setup_icon_entry (PanelDItemEditor *dialog,
+			      const char       *icon_name);
+
 static gboolean panel_ditem_editor_save         (PanelDItemEditor *dialog,
 						 gboolean          report_errors);
 static gboolean panel_ditem_editor_save_timeout (gpointer data);
@@ -248,6 +253,9 @@ panel_ditem_editor_constructor (GType                  type,
 
 	panel_ditem_editor_setup_ui (dialog);
 
+	if (dialog->priv->new_file)
+		setup_icon_entry (dialog, NULL);
+
 	return obj;
 }
 
@@ -715,6 +723,8 @@ panel_ditem_editor_setup_ui (PanelDItemEditor *dialog)
 				break;
 			}
 		} while (gtk_tree_model_iter_next (model, &iter));
+
+		gtk_widget_grab_focus (priv->type_combo);
 	} else if (type == PANEL_DITEM_EDITOR_TYPE_DIRECTORY) {
 		table_attach_label (GTK_TABLE (priv->table), priv->name_label,
 				    1, 2, 0, 1);
@@ -725,6 +735,8 @@ panel_ditem_editor_setup_ui (PanelDItemEditor *dialog)
 				    1, 2, 1, 2);
 		table_attach_entry (GTK_TABLE (priv->table), priv->comment_entry,
 				    2, 3, 1, 2);
+
+		gtk_widget_grab_focus (priv->name_entry);
 	} else {
 		table_attach_label (GTK_TABLE (priv->table), priv->name_label,
 				    1, 2, 0, 1);
@@ -740,6 +752,8 @@ panel_ditem_editor_setup_ui (PanelDItemEditor *dialog)
 				    1, 2, 2, 3);
 		table_attach_entry (GTK_TABLE (priv->table), priv->comment_entry,
 				    2, 3, 2, 3);
+
+		gtk_widget_grab_focus (priv->name_entry);
 	}
 
 	type_combo_changed (dialog);
@@ -756,8 +770,6 @@ panel_ditem_editor_setup_ui (PanelDItemEditor *dialog)
 	gtk_container_set_focus_chain (GTK_CONTAINER (priv->table),
 				       focus_chain);
 	g_list_free (focus_chain);
-
-	gtk_widget_grab_focus (priv->name_entry);
 }
 
 /*
@@ -810,6 +822,8 @@ panel_ditem_editor_command_changed (PanelDItemEditor *dialog)
 {
 	PanelDItemEditorType  type;
 	const char           *exec_or_uri;
+	GtkIconTheme         *icon_theme;
+	char                 *icon;
 
 	exec_or_uri = gtk_entry_get_text (GTK_ENTRY (dialog->priv->command_entry));
 
@@ -824,6 +838,22 @@ panel_ditem_editor_command_changed (PanelDItemEditor *dialog)
 		panel_util_key_file_remove_key (dialog->priv->key_file, "URL");
 		panel_util_key_file_set_string (dialog->priv->key_file, "Exec",
 						exec_or_uri);
+
+		icon_theme = gtk_icon_theme_get_for_screen (gtk_widget_get_screen (GTK_WIDGET (dialog)));
+		icon = guess_icon_from_exec (icon_theme,
+					     dialog->priv->key_file);
+		if (icon) {
+			char *current;
+
+			current = panel_util_key_file_get_locale_string (dialog->priv->key_file,
+									 "Icon");
+
+			if (!current || strcmp (icon, current))
+				setup_icon_entry (dialog, icon);
+
+			g_free (current);
+			g_free (icon);
+		}
 		break;
 	case PANEL_DITEM_EDITOR_TYPE_LINK:
 		panel_util_key_file_remove_key (dialog->priv->key_file, "Exec");
@@ -900,12 +930,15 @@ command_browse_chooser_response (GtkFileChooser   *chooser,
 				 PanelDItemEditor *dialog)
 {
 	char *uri;
+	char *text;
 
 	if (response_id == GTK_RESPONSE_ACCEPT) {
 		switch (panel_ditem_editor_get_item_type (dialog)) {
 		case PANEL_DITEM_EDITOR_TYPE_APPLICATION:
 		case PANEL_DITEM_EDITOR_TYPE_TERMINAL_APPLICATION:
-			uri = gtk_file_chooser_get_filename (GTK_FILE_CHOOSER (chooser));
+			text = gtk_file_chooser_get_filename (GTK_FILE_CHOOSER (chooser));
+			uri = panel_util_make_exec_uri_for_desktop (text);
+			g_free (text);
 			break;
 		case PANEL_DITEM_EDITOR_TYPE_LINK:
 			uri = gtk_file_chooser_get_uri (GTK_FILE_CHOOSER (chooser));
@@ -1054,7 +1087,7 @@ type_combo_changed (PanelDItemEditor *dialog)
 
 	switch (panel_ditem_editor_get_item_type (dialog)) {
 	case PANEL_DITEM_EDITOR_TYPE_APPLICATION:
-		text = _("_Command:");
+		text = _("Comm_and:");
 		if (dialog->priv->combo_setuped) {
 			panel_util_key_file_set_string (dialog->priv->key_file,
 							"Type", "Application");
@@ -1101,6 +1134,47 @@ type_combo_changed (PanelDItemEditor *dialog)
 	update_chooser_for_type (dialog);
 }
 
+static void
+setup_icon_entry (PanelDItemEditor *dialog,
+		  const char       *icon_name)
+{
+	char *buffer;
+	char *tmpstr;
+
+	if (!icon_name || icon_name[0] == '\0') {
+		if (panel_ditem_editor_get_item_type (dialog) == PANEL_DITEM_EDITOR_TYPE_DIRECTORY) {
+			buffer = g_strdup (PANEL_ICON_FOLDER);
+		} else {
+			buffer = g_strdup (PANEL_ICON_LAUNCHER);
+		}
+	} else {
+		buffer = g_strdup (icon_name);
+	}
+
+	tmpstr = panel_find_icon (gtk_icon_theme_get_for_screen (gtk_widget_get_screen (GTK_WIDGET (dialog))),
+				  buffer, 48);
+
+	g_free (dialog->priv->icon_theme_dir);
+	if (tmpstr != NULL && buffer != NULL && !g_path_is_absolute (buffer)) {
+		/* this is a themed icon, see bug #119208 */
+		dialog->priv->icon_theme_dir = g_path_get_dirname (tmpstr);
+		/* FIXME: what about theme changes when the dialog is up */
+	} else {
+		/* use the default pixmap directory as the standard
+		 * icon_theme_dir, since the standard directory is themed */
+		g_object_get (G_OBJECT (dialog->priv->icon_entry), "pixmap_subdir",
+			      &(dialog->priv->icon_theme_dir), NULL);
+	}
+
+	/* do this after we set icon_theme_dir since this will launch a
+	 * callback */
+	gnome_icon_entry_set_filename (GNOME_ICON_ENTRY (dialog->priv->icon_entry),
+				       tmpstr);
+
+	g_free (tmpstr);
+	g_free (buffer);
+}
+
 /* Conform display to ditem */
 void
 panel_ditem_editor_sync_display (PanelDItemEditor *dialog)
@@ -1110,7 +1184,6 @@ panel_ditem_editor_sync_display (PanelDItemEditor *dialog)
 	gboolean              run_in_terminal;
 	GKeyFile             *key_file;
 	char                 *buffer;
-	char                 *tmpstr;
 	GtkTreeIter           iter;
 	GtkTreeModel         *model;
 	PanelDItemEditorType  buf_type;
@@ -1176,24 +1249,7 @@ panel_ditem_editor_sync_display (PanelDItemEditor *dialog)
 
 	/* Icon */
 	buffer = panel_util_key_file_get_locale_string (key_file, "Icon");
-	tmpstr = panel_find_icon (gtk_icon_theme_get_for_screen (gtk_widget_get_screen (GTK_WIDGET (dialog))),
-				  buffer, 48);
-	gnome_icon_entry_set_filename (GNOME_ICON_ENTRY (dialog->priv->icon_entry),
-				       tmpstr);
-
-	g_free (dialog->priv->icon_theme_dir);
-	if (tmpstr != NULL && buffer != NULL && !g_path_is_absolute (buffer)) {
-		/* this is a themed icon, see bug #119208 */
-		dialog->priv->icon_theme_dir = g_path_get_dirname (tmpstr);
-		/* FIXME: what about theme changes when the dialog is up */
-	} else {
-		/* use the default pixmap directory as the standard
-		 * icon_theme_dir, since the standard directory is themed */
-		g_object_get (G_OBJECT (dialog->priv->icon_entry), "pixmap_subdir",
-			      &(dialog->priv->icon_theme_dir), NULL);
-	}
-
-	g_free (tmpstr);
+	setup_icon_entry (dialog, buffer);
 	g_free (buffer);
 
 	if (dialog->priv->save_timeout != 0) {
@@ -1209,8 +1265,6 @@ panel_ditem_editor_save (PanelDItemEditor *dialog,
 	PanelDItemEditorType  type;
 	GKeyFile             *key_file;
 	const char           *const_buf;
-	char                 *buffer;
-	char                 *C_value;
 	GError               *error;
 
 	g_return_val_if_fail (dialog != NULL, FALSE);
@@ -1263,45 +1317,9 @@ panel_ditem_editor_save (PanelDItemEditor *dialog,
 
 	key_file = dialog->priv->key_file;
 
-	/* Make sure we set the "C" locale strings to the terms we set here.
-	 * This is so that if the user logs into another locale they get their
-	 * own description there rather then empty. It is not the C locale
-	 * however, but the user created this entry herself so it's OK */
-	C_value = panel_util_key_file_get_string (key_file, "Name");
-	if (C_value == NULL || C_value [0] == '\0') {
-		buffer = panel_util_key_file_get_locale_string (key_file,
-								"Name");
-		if (buffer) {
-			panel_util_key_file_set_string (key_file, "Name",
-							buffer);
-			g_free (buffer);
-		}
-	}
-	g_free (C_value);
-
-	C_value = panel_util_key_file_get_string (key_file, "Comment");
-	if (C_value == NULL || C_value [0] == '\0') {
-		buffer = panel_util_key_file_get_locale_string (key_file,
-								"Comment");
-		if (buffer) {
-			panel_util_key_file_set_string (key_file, "Comment",
-							buffer);
-			g_free (buffer);
-		}
-	}
-	g_free (C_value);
-
-	C_value = panel_util_key_file_get_string (key_file, "Icon");
-	if (C_value == NULL || C_value [0] == '\0') {
-		buffer = panel_util_key_file_get_locale_string (key_file,
-								"Icon");
-		if (buffer) {
-			panel_util_key_file_set_string (key_file, "Icon",
-							buffer);
-			g_free (buffer);
-		}
-	}
-	g_free (C_value);
+	panel_util_key_file_ensure_C_key (key_file, "Name");
+	panel_util_key_file_ensure_C_key (key_file, "Comment");
+	panel_util_key_file_ensure_C_key (key_file, "Icon");
 
 	if (dialog->priv->save_uri) {
 		char *uri;
