@@ -32,7 +32,9 @@
 
 #include "panel-logout.h"
 #include "panel-gdm.h"
+#include "panel-power-manager.h"
 #include "panel-session.h"
+#include "panel-icon-names.h"
 
 #define PANEL_LOGOUT_DIALOG_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), PANEL_TYPE_LOGOUT_DIALOG, PanelLogoutDialogPrivate))
 
@@ -50,6 +52,8 @@ enum {
 struct _PanelLogoutDialogPrivate {
 	PanelLogoutDialogType type;
 
+	PanelPowerManager    *power_manager;
+
 	int                   timeout;
 	unsigned int          timeout_id;
 
@@ -60,9 +64,9 @@ static PanelLogoutDialog *current_dialog = NULL;
 
 static void panel_logout_destroy (PanelLogoutDialog *logout_dialog,
 				  gpointer           data);
-static void panel_logout_response (GtkWidget *logout_dialog,
-				   guint      response_id,
-				   gpointer   data);
+static void panel_logout_response (PanelLogoutDialog *logout_dialog,
+				   guint              response_id,
+				   gpointer           data);
 
 enum {
   PROP_0,
@@ -132,11 +136,14 @@ panel_logout_init (PanelLogoutDialog *logout_dialog)
 	logout_dialog->priv->timeout    = 0;
 	logout_dialog->priv->default_response = GTK_RESPONSE_CANCEL;
 
+	/* FIXME: we should most probably use gtk_window_set_transient_for(PANEL) */
 	gtk_window_set_skip_pager_hint (GTK_WINDOW (logout_dialog), TRUE);
 	gtk_window_set_skip_taskbar_hint (GTK_WINDOW (logout_dialog), TRUE);
 	gtk_window_set_keep_above (GTK_WINDOW (logout_dialog), TRUE);
 	gtk_window_stick (GTK_WINDOW (logout_dialog));
 
+	logout_dialog->priv->power_manager = panel_get_power_manager ();
+
 	g_signal_connect (logout_dialog, "destroy",
 			  G_CALLBACK (panel_logout_destroy), NULL);
 	g_signal_connect (logout_dialog, "response",
@@ -151,15 +158,21 @@ panel_logout_destroy (PanelLogoutDialog *logout_dialog,
 		g_source_remove (logout_dialog->priv->timeout_id);
 	logout_dialog->priv->timeout_id = 0;
 
+	g_object_unref (logout_dialog->priv->power_manager);
+	logout_dialog->priv->power_manager = NULL;
+
 	current_dialog = NULL;
 }
 
 static void
-panel_logout_response (GtkWidget *logout_dialog,
+panel_logout_response (PanelLogoutDialog *logout_dialog,
 		       guint      response_id,
 		       gpointer   data)
 {
-	gtk_widget_destroy (logout_dialog);
+	PanelPowerManager *power_manager;
+
+	power_manager = g_object_ref (logout_dialog->priv->power_manager);
+	gtk_widget_destroy (GTK_WIDGET (logout_dialog));
 
 	switch (response_id) {
 	case GTK_RESPONSE_CANCEL:
@@ -180,11 +193,12 @@ panel_logout_response (GtkWidget *logout_dialog,
 		panel_session_request_logout ();
 		break;
 	case PANEL_LOGOUT_RESPONSE_STD:
-		gdm_set_logout_action (GDM_LOGOUT_ACTION_SUSPEND);
-		panel_session_request_logout ();
+		if (panel_power_manager_can_hibernate (power_manager))
+			panel_power_manager_attempt_hibernate (power_manager);
 		break;
 	case PANEL_LOGOUT_RESPONSE_STR:
-		//FIXME
+		if (panel_power_manager_can_suspend (power_manager))
+			panel_power_manager_attempt_suspend (power_manager);
 		break;
 	case GTK_RESPONSE_NONE:
 	case GTK_RESPONSE_DELETE_EVENT:
@@ -192,6 +206,7 @@ panel_logout_response (GtkWidget *logout_dialog,
 	default:
 		g_assert_not_reached ();
 	}
+	g_object_unref (power_manager);
 }
 
 static gboolean
@@ -298,7 +313,7 @@ panel_logout_new (PanelLogoutDialogType  type,
 
 	switch (type) {
 	case PANEL_LOGOUT_DIALOG_LOGOUT:
-		icon_name      = "gnome-logout";
+		icon_name      = PANEL_ICON_LOGOUT;
 		primary_text   = _("Log out of this system now?");
 		// FIXME need to verify that this response can be used
 		logout_dialog->priv->default_response = PANEL_LOGOUT_DIALOG_LOGOUT;
@@ -315,26 +330,33 @@ panel_logout_new (PanelLogoutDialogType  type,
 				       PANEL_LOGOUT_RESPONSE_LOGOUT);
 		break;
 	case PANEL_LOGOUT_DIALOG_SHUTDOWN:
-		icon_name      = "gnome-shutdown";
+		icon_name      = PANEL_ICON_SHUTDOWN;
 		primary_text   = _("Shut down this system now?");
 
 		logout_dialog->priv->default_response = PANEL_LOGOUT_RESPONSE_SHUTDOWN;
-		//FIXME see previous FIXME
-
-		if (gdm_supports_logout_action (GDM_LOGOUT_ACTION_SUSPEND))
+		if (panel_power_manager_can_suspend (logout_dialog->priv->power_manager))
 			gtk_dialog_add_button (GTK_DIALOG (logout_dialog),
-					       _("_Suspend"),
+					       _("S_uspend"),
+					       PANEL_LOGOUT_RESPONSE_STR);
+
+		if (panel_power_manager_can_hibernate (logout_dialog->priv->power_manager))
+			gtk_dialog_add_button (GTK_DIALOG (logout_dialog),
+					       _("_Hibernate"),
 					       PANEL_LOGOUT_RESPONSE_STD);
 
-		gtk_dialog_add_button (GTK_DIALOG (logout_dialog),
-				       _("_Restart"),
-				       PANEL_LOGOUT_RESPONSE_REBOOT);
+		if (gdm_supports_logout_action (GDM_LOGOUT_ACTION_REBOOT))
+			gtk_dialog_add_button (GTK_DIALOG (logout_dialog),
+					       _("_Restart"),
+					       PANEL_LOGOUT_RESPONSE_REBOOT);
+
 		gtk_dialog_add_button (GTK_DIALOG (logout_dialog),
 				       GTK_STOCK_CANCEL,
 				       GTK_RESPONSE_CANCEL);
-		gtk_dialog_add_button (GTK_DIALOG (logout_dialog),
-				       _("_Shut Down"),
-				       PANEL_LOGOUT_RESPONSE_SHUTDOWN);
+
+		if (gdm_supports_logout_action (GDM_LOGOUT_ACTION_SHUTDOWN))
+			gtk_dialog_add_button (GTK_DIALOG (logout_dialog),
+					       _("_Shut Down"),
+					       PANEL_LOGOUT_RESPONSE_SHUTDOWN);
 		break;
 	default:
 		g_assert_not_reached ();
