@@ -29,8 +29,9 @@
 #include <string.h>
 #include <glib/gi18n.h>
 
+#include <gmenu-tree.h>
+
 #include "applet.h"
-#include "panel-compatibility.h"
 #include "panel-widget.h"
 #include "panel-util.h"
 #include "panel-profile.h"
@@ -38,6 +39,9 @@
 #include "menu.h"
 #include "panel-lockdown.h"
 #include "panel-a11y.h"
+#include "panel-icon-names.h"
+
+G_DEFINE_TYPE (PanelMenuButton, panel_menu_button, BUTTON_TYPE_WIDGET);
 
 #define PANEL_MENU_BUTTON_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), PANEL_TYPE_MENU_BUTTON, PanelMenuButtonPrivate))
 
@@ -56,7 +60,6 @@ typedef enum {
 	APPLICATIONS_MENU,
 #define DEFAULT_MENU      APPLICATIONS_MENU
 	SETTINGS_MENU,
-	PREFERENCES_MENU,
 	LAST_MENU
 } MenuPathRoot;
 
@@ -68,9 +71,7 @@ typedef struct {
 
 static MenuPathRootItem root_items [] = {
 	{ APPLICATIONS_MENU, "applications", "applications.menu" },
-	{ PREFERENCES_MENU,  "preferences",  "preferences.menu"  },
-	/* compatibility with GNOME < 2.17.90 */
-	{ SETTINGS_MENU,     "settings",     NULL                }
+	{ SETTINGS_MENU,     "settings",     "settings.menu"     }
 };
 
 struct _PanelMenuButtonPrivate {
@@ -96,8 +97,6 @@ static void panel_menu_button_set_icon              (PanelMenuButton *button);
 
 static AtkObject *panel_menu_button_get_accessible  (GtkWidget       *widget);
 
-static GObjectClass *parent_class;
-
 static const char *
 panel_menu_path_root_to_filename (MenuPathRoot path_root)
 {
@@ -163,8 +162,7 @@ panel_menu_scheme_to_path_root (const char *scheme)
 }
 
 static void
-panel_menu_button_instance_init (PanelMenuButton      *button,
-				 PanelMenuButtonClass *klass)
+panel_menu_button_init (PanelMenuButton *button)
 {
 	button->priv = PANEL_MENU_BUTTON_GET_PRIVATE (button);
 
@@ -209,7 +207,7 @@ panel_menu_button_finalize (GObject *object)
 	g_free (button->priv->tooltip);
 	button->priv->tooltip = NULL;
 
-	parent_class->finalize (object);
+	G_OBJECT_CLASS (panel_menu_button_parent_class)->finalize (object);
 }
 
 static void
@@ -316,8 +314,8 @@ panel_menu_button_parent_set (GtkWidget *widget,
 	panel_menu_button_associate_panel (button);
 	panel_menu_button_set_icon (button);
 
-	if (GTK_WIDGET_CLASS (parent_class)->parent_set)
-		GTK_WIDGET_CLASS (parent_class)->parent_set (widget, previous_parent);
+	if (GTK_WIDGET_CLASS (panel_menu_button_parent_class)->parent_set)
+		GTK_WIDGET_CLASS (panel_menu_button_parent_class)->parent_set (widget, previous_parent);
 }
 
 static void
@@ -445,8 +443,8 @@ panel_menu_button_pressed (GtkButton *gtk_button)
 
 	button = PANEL_MENU_BUTTON (gtk_button);
 
-	if (GTK_BUTTON_CLASS (parent_class)->pressed)
-		GTK_BUTTON_CLASS (parent_class)->pressed (gtk_button);
+	if (GTK_BUTTON_CLASS (panel_menu_button_parent_class)->pressed)
+		GTK_BUTTON_CLASS (panel_menu_button_parent_class)->pressed (gtk_button);
 
 	panel_menu_button_popup_menu (button, 0, gtk_get_current_event_time());
 }
@@ -461,8 +459,8 @@ panel_menu_button_clicked (GtkButton *gtk_button)
 
 	button = PANEL_MENU_BUTTON (gtk_button);
 
-	if (GTK_BUTTON_CLASS (parent_class)->clicked)
-		GTK_BUTTON_CLASS (parent_class)->clicked (gtk_button);
+	if (GTK_BUTTON_CLASS (panel_menu_button_parent_class)->clicked)
+		GTK_BUTTON_CLASS (panel_menu_button_parent_class)->clicked (gtk_button);
 
 	if ((event = gtk_get_current_event ())) {
 		panel_menu_button_popup_menu (button,
@@ -481,8 +479,6 @@ panel_menu_button_class_init (PanelMenuButtonClass *klass)
 	GtkWidgetClass *widget_class  = (GtkWidgetClass *) klass;
 	GtkButtonClass *button_class  = (GtkButtonClass *) klass;
 
-	parent_class = g_type_class_peek_parent (klass);
-
 	gobject_class->finalize     = panel_menu_button_finalize;
 	gobject_class->get_property = panel_menu_button_get_property;
 	gobject_class->set_property = panel_menu_button_set_property;
@@ -551,32 +547,6 @@ panel_menu_button_class_init (PanelMenuButtonClass *klass)
 					      G_PARAM_READWRITE));
 }
 
-GType
-panel_menu_button_get_type (void)
-{
-	static GType type = 0;
-
-	if (!type) {
-		static const GTypeInfo info = {
-			sizeof (PanelMenuButtonClass),
-			NULL,
-			NULL,
-			(GClassInitFunc) panel_menu_button_class_init,
-			NULL,
-			NULL,
-			sizeof (PanelMenuButton),
-			0,
-			(GInstanceInitFunc) panel_menu_button_instance_init,
-			NULL
-		};
-
-		type = g_type_register_static (
-				BUTTON_TYPE_WIDGET, "PanelMenuButton", &info, 0);
-	}
-
-	return type;
-}
-
 static void
 panel_menu_button_gconf_notify (GConfClient     *client,
 				guint            cnxn_id,
@@ -740,7 +710,7 @@ panel_menu_button_get_icon (PanelMenuButton *button)
 	}
 
 	if (!retval)
-		retval = g_strdup (PANEL_MAIN_MENU_ICON);
+		retval = g_strdup (PANEL_ICON_MAIN_MENU);
 
 	return retval;
 }
@@ -895,31 +865,19 @@ panel_menu_button_load_from_gconf (PanelWidget *panel,
 				   gboolean     exactpos,
 				   const char  *id)
 {
-	GConfClient  *client;
-	char         *scheme;
-	MenuPathRoot root;
-	const char   *key;
-	char         *menu_path;
-	char         *custom_icon;
-	char         *tooltip;
-	gboolean      use_menu_path;
-	gboolean      use_custom_icon;
+	GConfClient *client;
+	const char  *key;
+	char        *menu_path;
+	char        *custom_icon;
+	char        *tooltip;
+	gboolean     use_menu_path;
+	gboolean     use_custom_icon;
 
 	client  = panel_gconf_get_client ();
 
 	key = panel_gconf_full_key (PANEL_GCONF_OBJECTS, id, "menu_path");
 	menu_path = gconf_client_get_string (client, key, NULL);
 
-	scheme = g_strndup (menu_path, strcspn (menu_path, ":"));
-	root = panel_menu_scheme_to_path_root (scheme);
-	g_free (scheme);
-	if (root == SETTINGS_MENU) {
-		panel_compatiblity_migrate_settings_menu_button (panel_gconf_get_client (),
-								 id);
-		g_free (menu_path);
-		return;
-	}
-
 	key = panel_gconf_full_key (PANEL_GCONF_OBJECTS, id, "custom_icon");
 	custom_icon = gconf_client_get_string (client, key, NULL);
 
@@ -1089,6 +1047,7 @@ panel_menu_button_set_dnd_enabled (PanelMenuButton *button,
 #define PANEL_IS_MENU_BUTTON_ACCESSIBLE(o) (G_TYPE_CHECK_INSTANCE_TYPE ((o), panel_menu_button_accessible_get_type ()))
 
 static GType panel_menu_button_accessible_get_type (void);
+static gpointer parent_accessible_class = NULL;
 
 static int
 panel_menu_button_accessible_get_n_children (AtkObject *obj)
@@ -1115,15 +1074,34 @@ panel_menu_button_accessible_ref_child (AtkObject *obj,
 
 	if (!(menu = panel_menu_button_create_menu (button)))
 		return NULL;
+	/*
+	 * This ensures that the menu is populated with all menu items
+	 */
+	g_signal_emit_by_name (menu, "show", NULL);
 
 	return g_object_ref (gtk_widget_get_accessible (menu));
 }
 
+static G_CONST_RETURN gchar *
+panel_menu_button_accessible_get_name (AtkObject *obj)
+{
+	const char *name;
+
+	name = ATK_OBJECT_CLASS (parent_accessible_class)->get_name(obj);
+	if (name == NULL)
+		name = _("Main Menu");
+
+	return name;
+}
+
 static void
 panel_menu_button_accessible_class_init (AtkObjectClass *klass)
 {
 	klass->get_n_children = panel_menu_button_accessible_get_n_children;
 	klass->ref_child      = panel_menu_button_accessible_ref_child; 
+	klass->get_name       = panel_menu_button_accessible_get_name; 
+
+	parent_accessible_class = g_type_class_peek_parent (klass);
 }
 
 static GType
@@ -1211,5 +1189,5 @@ panel_menu_button_get_accessible (GtkWidget *widget)
 
 	first_time = FALSE;
 	 
-	return GTK_WIDGET_CLASS (parent_class)->get_accessible (widget);
+	return GTK_WIDGET_CLASS (panel_menu_button_parent_class)->get_accessible (widget);
 }
