@@ -21,6 +21,8 @@ void            panel_launch_desktop_file  (const char                   *deskto
 					    GdkScreen                    *screen,
 					    GError                      **error);
 
+char *          panel_util_make_exec_uri_for_desktop (const char *exec);
+
 void		panel_show_help		(GdkScreen  *screen,
 					 const char *path,
 					 const char *linkid);
@@ -75,10 +77,11 @@ GdkPixbuf *     panel_load_icon         (GtkIconTheme  *icon_theme,
 					 int            desired_width,
 					 int            desired_height,
 					 char         **error_msg);
-GdkPixbuf *	missing_pixbuf		(int size);
 
 char *panel_make_full_path   (const char *dir,
 			      const char *filename);
+char *panel_make_unique_desktop_path_from_name (const char *dir,
+						const char *name);
 char *panel_make_unique_desktop_uri (const char *dir,
 				     const char *source);
 char *panel_lookup_in_data_dirs (const char *basename);
@@ -116,6 +119,11 @@ void    panel_util_key_file_set_locale_string (GKeyFile    *keyfile,
 	g_key_file_remove_key (key_file, "Desktop Entry", key, NULL)
 void panel_util_key_file_remove_locale_key (GKeyFile    *keyfile,
 					    const gchar *key);
+void panel_util_key_file_ensure_C_key (GKeyFile   *keyfile,
+				       const char *key);
+
+char *guess_icon_from_exec (GtkIconTheme *icon_theme,
+			    GKeyFile     *key_file);
 
 G_END_DECLS
 
