@@ -46,6 +46,7 @@
 #include "panel-menu-button.h"
 #include "panel-globals.h"
 #include "panel-lockdown.h"
+#include "panel-icon-names.h"
 
 enum {
 	TARGET_URL,
@@ -269,12 +270,8 @@ panel_destroy (PanelToplevel *toplevel,
 	panel_lockdown_notify_remove (G_CALLBACK (panel_recreate_context_menu),
 				      pd);
 
-	if (pd->menu) {
-		g_signal_handlers_disconnect_by_func (pd->menu,
-						      context_menu_deactivate,
-						      pd);
+	if (pd->menu)
 		g_object_unref (pd->menu);
-	}
 	pd->menu = NULL;
 
 	pd->panel = NULL;
@@ -305,18 +302,21 @@ static GtkWidget *
 panel_menu_get (PanelWidget *panel, PanelData *pd)
 {
 	if (!pd->menu) {
-		pd->menu = g_object_ref_sink (panel_context_menu_create (panel));
-		g_signal_connect (pd->menu, "deactivate",
-				  G_CALLBACK (context_menu_deactivate),
-				  pd);
-		g_signal_connect (pd->menu, "show",
-				  G_CALLBACK (context_menu_show), pd);
+		pd->menu = g_object_ref (panel_context_menu_create (panel));
+		if (pd->menu) {
+			gtk_object_sink (GTK_OBJECT (pd->menu));
+			g_signal_connect (pd->menu, "deactivate",
+					  G_CALLBACK (context_menu_deactivate),
+					  pd);
+			g_signal_connect (pd->menu, "show",
+					  G_CALLBACK (context_menu_show), pd);
+		}
 	}
 
 	return pd->menu;
 }
 
-static GtkWidget *
+GtkWidget *
 make_popup_panel_menu (PanelWidget *panel_widget)
 {
 	PanelData *pd;
@@ -483,7 +483,7 @@ drop_url (PanelWidget *panel,
 
 	panel_launcher_create_from_info (panel->toplevel, position, FALSE,
 					 netscape_url[NETSCAPE_URL_URL],
-					 name, comment, "gnome-globe");
+					 name, comment, PANEL_ICON_REMOTE);
 
 	g_free (comment);
 	g_strfreev (netscape_url);
@@ -662,7 +662,7 @@ drop_urilist (PanelWidget *panel,
 							  NULL);
 
 				if (!icon)
-					icon = g_strdup ("gnome-unknown");
+					icon = g_strdup (PANEL_ICON_UNKNOWN);
 
 				if (!drop_uri (panel, pos, uri, icon))
 					success = FALSE;
@@ -670,7 +670,7 @@ drop_urilist (PanelWidget *panel,
 				g_free (icon);
 			}
 		} else {
-			if (!drop_uri (panel, pos, uri, "gnome-unknown"))
+			if (!drop_uri (panel, pos, uri, PANEL_ICON_UNKNOWN))
 				success = FALSE;
 		}
 
@@ -1083,7 +1083,7 @@ panel_receive_dnd_data (PanelWidget      *panel,
 		break;
 	case TARGET_DIRECTORY:
 		success = drop_uri (panel, pos, (char *)selection_data->data,
-				    "gnome-fs-directory");
+				    PANEL_ICON_FOLDER);
 		break;
 	case TARGET_APPLET:
 		if (!selection_data->data) {
@@ -1333,9 +1333,6 @@ panel_deletion_dialog (PanelToplevel *toplevel)
 	gtk_dialog_set_default_response (GTK_DIALOG (dialog), GTK_RESPONSE_OK);
 	gtk_window_set_title (GTK_WINDOW (dialog), title);
 
-	gtk_window_set_wmclass (GTK_WINDOW (dialog),
-				"panel_remove_query", "Panel");
-
 	gtk_window_set_screen (GTK_WINDOW (dialog),
 				gtk_window_get_screen (GTK_WINDOW (toplevel)));
 
